@@ -2247,9 +2247,7 @@ bool File_Ac3::FrameSynchPoint_Test()
         else if (bsid>0x0A && bsid<=0x10)
         {
             int16u frmsiz=CC2(Buffer+Buffer_Offset+2)&0x07FF;
-            int8u  strmtyp=Buffer[Buffer_Offset+Size+2]>>6;
-            if (strmtyp!=1) //Not dependent stream
-                Size=2+frmsiz*2;
+            Size=2+frmsiz*2;
         }
         if (Size>=6)
         {
