@@ -597,8 +597,13 @@ enum video
     Video_ScanType_String,
     Video_ScanType_Original,
     Video_ScanType_Original_String,
+    Video_ScanType_StoreMethod,
+    Video_ScanType_StoreMethod_FieldsPerBlock,
+    Video_ScanType_StoreMethod_String,
     Video_ScanOrder,
     Video_ScanOrder_String,
+    Video_ScanOrder_Stored,
+    Video_ScanOrder_Stored_String,
     Video_ScanOrder_StoredDisplayedInverted,
     Video_ScanOrder_Original,
     Video_ScanOrder_Original_String,
