@@ -180,7 +180,7 @@
 /* The callback function                                                   */
 /***************************************************************************/
 
-#if !defined(__WINDOWS__)
+#if !defined(__WINDOWS__) && !defined(__stdcall)
     #define __stdcall
 #endif //!defined(__WINDOWS__)
 
@@ -546,6 +546,12 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
 
 #define MediaInfo_Parser_Aaf            0x6A
 
+/***************************************************************************/
+/* DXW                                                                     */
+/***************************************************************************/
+
+#define MediaInfo_Parser_Dxw            0x6B
+
 /***************************************************************************/
 /* MPEG Video                                                              */
 /***************************************************************************/
@@ -636,6 +642,12 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
 
 #define MediaInfo_Parser_ChannelGrouping 0xA7
 
+/***************************************************************************/
+/* JPEG                                                                    */
+/***************************************************************************/
+
+#define MediaInfo_Parser_Jpeg           0xC0
+
 /***************************************************************************/
 /* CEA-608 (formely IEA-608)                                               */
 /***************************************************************************/
