@@ -167,6 +167,32 @@ File_Lxf::~File_Lxf()
             delete Audios[Pos].Parsers[Pos2];
 }
 
+//***************************************************************************
+// Buffer - File header
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+bool File_Lxf::FileHeader_Begin()
+{
+    //Synchro
+    if (8>Buffer_Size)
+        return false;
+    if (Buffer[0]!=0x4C //"LEITCH"
+     || Buffer[1]!=0x45
+     || Buffer[2]!=0x49
+     || Buffer[3]!=0x54
+     || Buffer[4]!=0x43
+     || Buffer[5]!=0x48
+     || Buffer[6]!=0x00
+     || Buffer[7]!=0x00)
+    {
+        Reject();
+        return false;
+    }
+
+    return true;
+}
+
 //***************************************************************************
 // Streams management
 //***************************************************************************
