@@ -29,9 +29,12 @@
 #include "ZenLib/Format/Http/Http_Utils.h"
 #include <set>
 #include <algorithm>
+#include <cfloat>
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Events_Internal.h"
+    #include "MediaInfo/MediaInfo_Config_PerPackage.h"
 #endif //MEDIAINFO_EVENTS
+using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -131,30 +134,41 @@ void File__ReferenceFilesHelper_InfoFromFileName (File__ReferenceFilesHelper::re
             const Ztring &Test=List[Pos][List[Pos].size()-1-Pos2];
 
             //ChannelLayout
-            if (Test!=__T("l")
+            if (ChannelLayout_Pos==(size_t)-1
+             && Test!=__T("l")
              && Test!=__T("r")
+             && Test!=__T("lt")
+             && Test!=__T("rt")
              && Test!=__T("c")
+             && Test!=__T("lf")
              && Test!=__T("lfe")
              && Test!=__T("sub")
              && Test!=__T("ls")
              && Test!=__T("rs")
-             && Test!=__T("b"))
+             && Test!=__T("b")
+             && Test!=__T("mono"))
                 IsChannelLayout=false;
 
             //Language
-            if (Test!=__T("deu")
+            if (Language_Pos==(size_t)-1
+             && Test!=__T("ara")
+             && Test!=__T("deu")
              && Test!=__T("eng")
              && Test!=__T("fra")
              && Test!=__T("fre")
              && Test!=__T("ita")
+             && Test!=__T("jpn")
+             && Test!=__T("rus")
              && Test!=__T("spa"))
                 IsLanguage=false;
         }
 
-        if (IsChannelLayout)
+        if (IsChannelLayout && ChannelLayout_Pos==(size_t)-1)
             ChannelLayout_Pos=Pos2;
-        if (IsLanguage)
+        if (IsLanguage && Language_Pos==(size_t)-1)
             Language_Pos=Pos2;
+        if (ChannelLayout_Pos!=(size_t)-1 && Language_Pos!=(size_t)-1)
+            break;
     }
 
     //ChannelLayout
@@ -168,19 +182,31 @@ void File__ReferenceFilesHelper_InfoFromFileName (File__ReferenceFilesHelper::re
                 ChannelPositions2=__T("1/0/0");
                 ChannelLayout=__T("L");
             }
+            if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("lt"))
+            {
+                ChannelPositions=__T("Front: Lt");
+                ChannelPositions2=__T("1/0/0");
+                ChannelLayout=__T("Lt");
+            }
+            if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("rt"))
+            {
+                ChannelPositions=__T("Front: Rt");
+                ChannelPositions2=__T("1/0/0");
+                ChannelLayout=__T("Rt");
+            }
             if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("r"))
             {
                 ChannelPositions=__T("Front: R");
                 ChannelPositions2=__T("1/0/0");
                 ChannelLayout=__T("R");
             }
-            if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("c"))
+            if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("c") || List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("mono"))
             {
                 ChannelPositions=__T("Front: C");
                 ChannelPositions2=__T("1/0/0");
                 ChannelLayout=__T("C");
             }
-            if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("lfe") || List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("sub"))
+            if (List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("lf") || List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("lfe") || List[Pos][List[Pos].size()-1-ChannelLayout_Pos]==__T("sub"))
             {
                 ChannelPositions=__T("LFE");
                 ChannelPositions2=__T(".1");
@@ -213,21 +239,29 @@ void File__ReferenceFilesHelper_InfoFromFileName (File__ReferenceFilesHelper::re
     //Language
     if (Language_Pos!=(size_t)-1)
         for (size_t Pos=0; Pos<List.size(); Pos++)
-        {
-            Ztring Language;
-            if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("deu"))
-                Language=__T("de");
-            if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("eng"))
-                Language=__T("en");
-            if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("fra") || List[Pos][List[Pos].size()-1-Language_Pos]==__T("fre"))
-                Language=__T("fr");
-            if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("ita"))
-                Language=__T("it");
-            if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("spa"))
-                Language=__T("es");
+            if (1+Language_Pos<List[Pos].size())
+            {
+                Ztring Language;
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("ara"))
+                    Language=__T("ar");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("deu"))
+                    Language=__T("de");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("eng"))
+                    Language=__T("en");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("fra") || List[Pos][List[Pos].size()-1-Language_Pos]==__T("fre"))
+                    Language=__T("fr");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("ita"))
+                    Language=__T("it");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("jpn"))
+                    Language=__T("ja");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("rus"))
+                    Language=__T("ru");
+                if (List[Pos][List[Pos].size()-1-Language_Pos]==__T("spa"))
+                    Language=__T("es");
 
-            (*Iterators[Pos]).Infos["Language"]=Language;
-        }
+                if (!Language.empty())
+                    (*Iterators[Pos]).Infos["Language"]=Language;
+            }
 }
 void File__ReferenceFilesHelper::ParseReferences()
 {
@@ -243,6 +277,51 @@ void File__ReferenceFilesHelper::ParseReferences()
                     }
         #endif //MEDIAINFO_FILTER
 
+        //Filling Filenames from the more complete version and Edit rates
+        float64 EditRate=DBL_MAX;
+        size_t  EditRate_Count=0;
+        for (Reference=References.begin(); Reference!=References.end(); Reference++)
+            if (Reference->FileNames.empty())
+                for (size_t Pos=0; Pos<Reference->CompleteDuration.size(); Pos++)
+                {
+                    Reference->FileNames.push_back(Reference->CompleteDuration[Pos].FileName);
+                    if (Reference->CompleteDuration[Pos].IgnoreFramesRate && EditRate!=Reference->CompleteDuration[Pos].IgnoreFramesRate)
+                    {
+                        if (EditRate>Reference->CompleteDuration[Pos].IgnoreFramesRate)
+                            EditRate=Reference->CompleteDuration[Pos].IgnoreFramesRate;
+                        EditRate_Count++;
+                    }
+                }
+        if (EditRate_Count>1)
+            //Multiple rates, using only one rate
+            for (Reference=References.begin(); Reference!=References.end(); Reference++)
+                for (size_t Pos=0; Pos<Reference->CompleteDuration.size(); Pos++)
+                    if (Reference->CompleteDuration[Pos].IgnoreFramesRate && EditRate!=Reference->CompleteDuration[Pos].IgnoreFramesRate)
+                    {
+                        if (Reference->CompleteDuration[Pos].IgnoreFramesBefore)
+                        {
+                            float64 Temp=(float64)Reference->CompleteDuration[Pos].IgnoreFramesBefore;
+                            Temp/=Reference->CompleteDuration[Pos].IgnoreFramesRate;
+                            Temp*=EditRate;
+                            Reference->CompleteDuration[Pos].IgnoreFramesBefore=float64_int64s(Temp);
+                        }
+                        if (Reference->CompleteDuration[Pos].IgnoreFramesAfter!=(int64u)-1)
+                        {
+                            float64 Temp=(float64)Reference->CompleteDuration[Pos].IgnoreFramesAfter;
+                            Temp/=Reference->CompleteDuration[Pos].IgnoreFramesRate;
+                            Temp*=EditRate;
+                            Reference->CompleteDuration[Pos].IgnoreFramesAfter=float64_int64s(Temp);
+                        }
+                        if (Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration!=(int64u)-1)
+                        {
+                            float64 Temp=(float64)Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration;
+                            Temp/=Reference->CompleteDuration[Pos].IgnoreFramesRate;
+                            Temp*=EditRate;
+                            Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration=float64_int64s(Temp);
+                        }
+                        Reference->CompleteDuration[Pos].IgnoreFramesRate=EditRate;
+                    }
+
         //Testing IDs
         std::set<int64u> StreamList;
         bool StreamList_DuplicatedIds=false;
@@ -258,7 +337,12 @@ void File__ReferenceFilesHelper::ParseReferences()
             for (Reference=References.begin(); Reference<References.end(); ++Reference)
                 (*Reference).StreamID=Reference-References.begin()+1;
         if (References.size()==1 && References.begin()->StreamID==(int64u)-1)
+        {
             ContainerHasNoId=true;
+            #if MEDIAINFO_EVENTS
+                MI->StreamIDs_Width[MI->StreamIDs_Size-1]=0;
+            #endif //MEDIAINFO_EVENTS
+        }
         std::sort(References.begin(), References.end(), File__ReferenceFilesHelper_Algo1);
         std::sort(References.begin(), References.end(), File__ReferenceFilesHelper_Algo2);
         std::sort(References.begin(), References.end(), File__ReferenceFilesHelper_Algo3);
@@ -266,6 +350,14 @@ void File__ReferenceFilesHelper::ParseReferences()
         //InfoFromFileName
         File__ReferenceFilesHelper_InfoFromFileName(References);
 
+        #if MEDIAINFO_EVENTS
+            if (MI->Config->Config_PerPackage==NULL)
+            {
+                MI->Config->Config_PerPackage=new MediaInfo_Config_PerPackage;
+                MI->Config->Config_PerPackage->CountOfPackages=References.size();
+            }
+        #endif //MEDIAINFO_EVENTS
+
         //Configuring file names
         Reference=References.begin();
         while (Reference!=References.end())
@@ -458,7 +550,7 @@ void File__ReferenceFilesHelper::ParseReferences()
                 if (Reference->StreamKind!=Stream_Max)
                 {
                     MI->Fill(Reference->StreamKind, Reference->StreamPos, "Source_Info", "Missing");
-                    if (MI->Retrieve(Reference->StreamKind, Reference->StreamPos, General_ID).empty())
+                    if (MI->Retrieve(Reference->StreamKind, Reference->StreamPos, General_ID).empty() && Reference->StreamID!=(int64u)-1)
                         MI->Fill(Reference->StreamKind, Reference->StreamPos, General_ID, Reference->StreamID);
                     for (std::map<string, Ztring>::iterator Info=Reference->Infos.begin(); Info!=Reference->Infos.end(); ++Info)
                     {
@@ -470,13 +562,13 @@ void File__ReferenceFilesHelper::ParseReferences()
                 }
             }
 
-            if (FilesForStorage && Reference->FileNames.size()>1)
+            if (FilesForStorage)
             {
                 for (size_t Pos=0; Pos<Reference->FileNames.size(); Pos++)
                 {
-                    reference::completeduration* Temp=new reference::completeduration;
-                    Temp->FileName=Reference->FileNames[Pos];
-                    Reference->CompleteDuration.push_back(Temp);
+                    if (Pos>=Reference->CompleteDuration.size())
+                        Reference->CompleteDuration.resize(Pos+1);
+                    Reference->CompleteDuration[Pos].FileName=Reference->FileNames[Pos];
                 }
                 Reference->FileNames.resize(1);
             }
@@ -494,7 +586,7 @@ void File__ReferenceFilesHelper::ParseReferences()
                     for (references::iterator ReferenceSource=References.begin(); ReferenceSource!=References.end(); ++ReferenceSource)
                         if (ReferenceSource->FileNames.empty())
                             CountOfReferencesToParse--;
-                    DTS_Interval=3000000000; // 3 seconds
+                    DTS_Interval=3000000000LL; // 3 seconds
                 }
             }
             else
@@ -583,7 +675,7 @@ void File__ReferenceFilesHelper::ParseReferences()
                     {
                         int64u DTS_Temp;
                         if (ReferenceTemp->CompleteDuration_Pos)
-                            DTS_Temp=ReferenceTemp->CompleteDuration[ReferenceTemp->CompleteDuration_Pos]->MI->Info->FrameInfo.DTS;
+                            DTS_Temp=ReferenceTemp->CompleteDuration[ReferenceTemp->CompleteDuration_Pos].MI->Info->FrameInfo.DTS;
                         else
                             DTS_Temp=ReferenceTemp->MI->Info->FrameInfo.DTS;
                         if (DTS_Minimal>DTS_Temp)
@@ -606,7 +698,7 @@ void File__ReferenceFilesHelper::ParseReferences()
         #endif //MEDIAINFO_EVENTS
 
         #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
-            if (Demux_Interleave)
+            if (Demux_Interleave && (Reference->MI==NULL || Reference->MI->Info==NULL || Reference->MI->Info->Demux_CurrentParser==NULL || Reference->MI->Info->Demux_CurrentParser->Demux_TotalBytes>=Reference->MI->Info->Demux_CurrentParser->Buffer_TotalBytes+Reference->MI->Info->Demux_CurrentParser->Buffer_Size))
             {
                 references::iterator Reference_Next=Reference; ++Reference_Next;
 
@@ -658,7 +750,7 @@ bool File__ReferenceFilesHelper::ParseReference_Init()
             Ztring Demux_Save=MI2.Option(__T("Demux_Get"), __T(""));
             MI2.Option(__T("ParseSpeed"), __T("0"));
             MI2.Option(__T("Demux"), Ztring());
-            size_t MiOpenResult=MI2.Open(Reference->CompleteDuration[Pos]->FileName);
+            size_t MiOpenResult=MI2.Open(Reference->CompleteDuration[Pos].FileName);
             MI2.Option(__T("ParseSpeed"), ParseSpeed_Save); //This is a global value, need to reset it. TODO: local value
             MI2.Option(__T("Demux"), Demux_Save); //This is a global value, need to reset it. TODO: local value
             if (MiOpenResult)
@@ -671,35 +763,47 @@ bool File__ReferenceFilesHelper::ParseReference_Init()
                         int64u Delay=MI2.Get(Stream_Video, 0, Video_Delay).To_int64u()*1000000;
                         if (Reference->StreamKind==Stream_Video && Offset_Video_DTS==0)
                             Offset_Video_DTS=Delay;
-                        Reference->CompleteDuration[0]->Demux_Offset_DTS=Offset_Video_DTS;
-                        Reference->CompleteDuration[0]->Demux_Offset_Frame=0;
+                        Reference->CompleteDuration[0].Demux_Offset_DTS=Offset_Video_DTS;
+                        Reference->CompleteDuration[0].Demux_Offset_Frame=0;
                     }
                     if (Pos+1<Reference->CompleteDuration.size())
                     {
-                        Reference->CompleteDuration[Pos+1]->Demux_Offset_DTS=Reference->CompleteDuration[Pos]->Demux_Offset_DTS+Duration;
-                        Reference->CompleteDuration[Pos+1]->Demux_Offset_Frame=Reference->CompleteDuration[Pos]->Demux_Offset_Frame+FrameCount;
+                        Reference->CompleteDuration[Pos+1].Demux_Offset_DTS=Reference->CompleteDuration[Pos].Demux_Offset_DTS+Duration;
+                        Reference->CompleteDuration[Pos+1].Demux_Offset_Frame=Reference->CompleteDuration[Pos].Demux_Offset_Frame+FrameCount;
                     }
                     else
-                        Duration=Reference->CompleteDuration[Pos]->Demux_Offset_DTS+Duration-Reference->CompleteDuration[0]->Demux_Offset_DTS;
+                        Duration=Reference->CompleteDuration[Pos].Demux_Offset_DTS+Duration-Reference->CompleteDuration[0].Demux_Offset_DTS;
                 #endif //MEDIAINFO_DEMUX
             }
 
             if (Pos)
             {
-                Reference->CompleteDuration[Pos]->MI=MI_Create();
+                Reference->CompleteDuration[Pos].MI=MI_Create();
+                Reference->CompleteDuration[Pos].MI->Config.File_IgnoreFramesBefore=Reference->CompleteDuration[Pos].IgnoreFramesBefore;
+                if (Reference->CompleteDuration[Pos].IgnoreFramesAfter==(int64u)-1 && Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration!=(int64u)-1)
+                    Reference->CompleteDuration[Pos].MI->Config.File_IgnoreFramesAfter=Reference->CompleteDuration[Pos].IgnoreFramesBefore+Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration;
+                else
+                    Reference->CompleteDuration[Pos].MI->Config.File_IgnoreFramesAfter=Reference->CompleteDuration[Pos].IgnoreFramesAfter;
+                Reference->CompleteDuration[Pos].MI->Config.File_IgnoreFramesRate=Reference->CompleteDuration[Pos].IgnoreFramesRate;
                 #if MEDIAINFO_DEMUX
-                    Reference->CompleteDuration[Pos]->MI->Config.Demux_Offset_Frame=Reference->CompleteDuration[Pos]->Demux_Offset_Frame;
-                    Reference->CompleteDuration[Pos]->MI->Config.Demux_Offset_DTS=Reference->CompleteDuration[Pos]->Demux_Offset_DTS;
+                    Reference->CompleteDuration[Pos].MI->Config.Demux_Offset_Frame=Reference->CompleteDuration[Pos].Demux_Offset_Frame;
+                    Reference->CompleteDuration[Pos].MI->Config.Demux_Offset_DTS=Reference->CompleteDuration[Pos].Demux_Offset_DTS;
                 #endif //MEDIAINFO_DEMUX
             }
         }
-        #if MEDIAINFO_DEMUX
-            if (!Reference->CompleteDuration.empty())
-            {
-                Reference->MI->Config.Demux_Offset_Frame=Reference->CompleteDuration[0]->Demux_Offset_Frame;
-                Reference->MI->Config.Demux_Offset_DTS=Reference->CompleteDuration[0]->Demux_Offset_DTS;
-            }
-        #endif //MEDIAINFO_DEMUX
+        if (!Reference->CompleteDuration.empty())
+        {
+            Reference->MI->Config.File_IgnoreFramesBefore=Reference->CompleteDuration[0].IgnoreFramesBefore;
+            if (Reference->CompleteDuration[0].IgnoreFramesAfter==(int64u)-1 && Reference->CompleteDuration[0].IgnoreFramesAfterDuration!=(int64u)-1)
+                Reference->MI->Config.File_IgnoreFramesAfter=Reference->CompleteDuration[0].IgnoreFramesBefore+Reference->CompleteDuration[0].IgnoreFramesAfterDuration;
+            else
+                Reference->MI->Config.File_IgnoreFramesAfter=Reference->CompleteDuration[0].IgnoreFramesAfter;
+            Reference->MI->Config.File_IgnoreFramesRate=Reference->CompleteDuration[0].IgnoreFramesRate;
+            #if MEDIAINFO_DEMUX
+                Reference->MI->Config.Demux_Offset_Frame=Reference->CompleteDuration[0].Demux_Offset_Frame;
+                Reference->MI->Config.Demux_Offset_DTS=Reference->CompleteDuration[0].Demux_Offset_DTS;
+            #endif //MEDIAINFO_DEMUX
+        }
     }
 
     if (Reference->IsCircular)
@@ -727,7 +831,6 @@ bool File__ReferenceFilesHelper::ParseReference_Init()
         #endif //MEDIAINFO_EVENTS
         if (!Reference->MI->Open(Reference->FileNames.Read()))
         {
-            MI->Fill(Reference->StreamKind, Reference->StreamPos, "Source_Info", "Missing");
             if (!Config->File_KeepInfo_Get())
             {
                 #if MEDIAINFO_DEMUX
@@ -745,7 +848,7 @@ bool File__ReferenceFilesHelper::ParseReference_Init()
 
         if (Config->ParseSpeed>=1)
             for (size_t Pos=1; Pos<Reference->CompleteDuration.size(); Pos++)
-                Reference->CompleteDuration[Pos]->MI->Open(Reference->CompleteDuration[Pos]->FileName);
+                Reference->CompleteDuration[Pos].MI->Open(Reference->CompleteDuration[Pos].FileName);
 
         #if MEDIAINFO_NEXTPACKET && MEDIAINFO_DEMUX
             if (Config->NextPacket_Get())
@@ -772,9 +875,17 @@ void File__ReferenceFilesHelper::ParseReference()
             {
                 int64u DTS_Temp;
                 if (Reference->CompleteDuration_Pos)
-                    DTS_Temp=Reference->CompleteDuration[Reference->CompleteDuration_Pos]->MI->Info->FrameInfo.DTS;
+                    DTS_Temp=Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI->Info->FrameInfo.DTS;
                 else
                     DTS_Temp=Reference->MI->Info->FrameInfo.DTS;
+                if (Reference->CompleteDuration_Pos<Reference->CompleteDuration.size() && Reference->CompleteDuration[Reference->CompleteDuration_Pos].IgnoreFramesRate && Reference->CompleteDuration[Reference->CompleteDuration_Pos].IgnoreFramesBefore)
+                {
+                    int64u TimeOffset=float64_int64s(((float64)Reference->CompleteDuration[Reference->CompleteDuration_Pos].IgnoreFramesBefore)/Reference->CompleteDuration[Reference->CompleteDuration_Pos].IgnoreFramesRate*1000000000);
+                    if (DTS_Temp>TimeOffset)
+                        DTS_Temp-=TimeOffset;
+                    else
+                        DTS_Temp=0;
+                }
                 if (DTS_Temp>DTS_Minimal+DTS_Interval)
                     return;
             }
@@ -802,7 +913,7 @@ void File__ReferenceFilesHelper::ParseReference()
 
                     while (Reference->CompleteDuration_Pos<Reference->CompleteDuration.size())
                     {
-                        while ((Reference->Status=Reference->CompleteDuration[Reference->CompleteDuration_Pos]->MI->Open_NextPacket())[8])
+                        while ((Reference->Status=Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI->Open_NextPacket())[8])
                         {
                                 if (Config->Event_CallBackFunction_IsSet())
                                 {
@@ -825,11 +936,11 @@ void File__ReferenceFilesHelper::ParseReference()
             Reference->State=10000;
             if (Reference->CompleteDuration.empty())
                 Reference->FileSize=Reference->MI->Config.File_Size;
-            else
+            else if (Reference->FileSize==(int64u)-1)
             {
                 Reference->FileSize=0;
                 for (size_t Pos=0; Pos<Reference->CompleteDuration.size(); Pos++)
-                    Reference->FileSize+=File::Size_Get(Reference->CompleteDuration[Pos]->FileName);
+                    Reference->FileSize+=File::Size_Get(Reference->CompleteDuration[Pos].FileName);
             }
             delete Reference->MI; Reference->MI=NULL;
         }
@@ -931,9 +1042,11 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
         MI->Clear(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_FrameCount));
         MI->Clear(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_StreamSize));
 
+        float64 BitRate_Before=0;
         int64u Duration_Temp=0;
         int64u FrameCount_Temp=0;
         int64u StreamSize_Temp=0;
+        int64u FileSize_Temp=0;
         for (size_t Pos=0; Pos<Reference->CompleteDuration.size(); Pos++)
         {
             MediaInfo_Internal MI2;
@@ -942,26 +1055,46 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
             Ztring Demux_Save=MI2.Option(__T("Demux_Get"), __T(""));
             MI2.Option(__T("ParseSpeed"), __T("0"));
             MI2.Option(__T("Demux"), Ztring());
-            size_t MiOpenResult=MI2.Open(Reference->CompleteDuration[Pos]->FileName);
+            MI2.Config.File_IgnoreFramesBefore=Reference->CompleteDuration[Pos].IgnoreFramesBefore;
+            if (Reference->CompleteDuration[Pos].IgnoreFramesAfter==(int64u)-1 && Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration!=(int64u)-1)
+                MI2.Config.File_IgnoreFramesAfter=Reference->CompleteDuration[Pos].IgnoreFramesBefore+Reference->CompleteDuration[Pos].IgnoreFramesAfterDuration;
+            else
+                MI2.Config.File_IgnoreFramesAfter=Reference->CompleteDuration[Pos].IgnoreFramesAfter;
+            MI2.Config.File_IgnoreFramesRate=Reference->CompleteDuration[Pos].IgnoreFramesRate;
+            size_t MiOpenResult=MI2.Open(Reference->CompleteDuration[Pos].FileName);
             MI2.Option(__T("ParseSpeed"), ParseSpeed_Save); //This is a global value, need to reset it. TODO: local value
             MI2.Option(__T("Demux"), Demux_Save); //This is a global value, need to reset it. TODO: local value
             if (MiOpenResult)
             {
+                BitRate_Before=MI2.Get(StreamKind_Last, StreamPos_From, MI->Fill_Parameter(StreamKind_Last, Generic_BitRate)).To_float64();
                 Ztring Duration_Temp2=MI2.Get(StreamKind_Last, StreamPos_From, MI->Fill_Parameter(StreamKind_Last, Generic_Duration));
-                if (!Duration_Temp2.empty())
+                if (!Duration_Temp2.empty() && Duration_Temp!=(int64u)-1)
                     Duration_Temp+=Duration_Temp2.To_int64u();
                 else
                     Duration_Temp=(int64u)-1;
                 Ztring FrameCount_Temp2=MI2.Get(StreamKind_Last, StreamPos_From, MI->Fill_Parameter(StreamKind_Last, Generic_FrameCount));
-                if (!FrameCount_Temp2.empty())
+                if (!FrameCount_Temp2.empty() && FrameCount_Temp!=(int64u)-1)
                     FrameCount_Temp+=FrameCount_Temp2.To_int64u();
                 else
                     FrameCount_Temp=(int64u)-1;
                 Ztring StreamSize_Temp2=MI2.Get(StreamKind_Last, StreamPos_From, MI->Fill_Parameter(StreamKind_Last, Generic_StreamSize));
-                if (!StreamSize_Temp2.empty())
+                if (!StreamSize_Temp2.empty() && StreamSize_Temp!=(int64u)-1)
                     StreamSize_Temp+=StreamSize_Temp2.To_int64u();
                 else
                     StreamSize_Temp=(int64u)-1;
+                Ztring FileSize_Temp2=MI2.Get(Stream_General, 0, General_FileSize);
+                if (!FileSize_Temp2.empty() && FileSize_Temp!=(int64u)-1)
+                    FileSize_Temp+=FileSize_Temp2.To_int64u();
+                else
+                    FileSize_Temp=(int64u)-1;
+            }
+            else
+            {
+                Duration_Temp=(int64u)-1;
+                FrameCount_Temp=(int64u)-1;
+                StreamSize_Temp=(int64u)-1;
+                FileSize_Temp=(int64u)-1;
+                break;
             }
         }
 
@@ -971,6 +1104,14 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
             MI->Fill(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_FrameCount), FrameCount_Temp, 10, true);
         if (StreamSize_Temp!=(int64u)-1)
             MI->Fill(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_StreamSize), StreamSize_Temp, 10, true);
+        if (FileSize_Temp!=(int64u)-1)
+            Reference->FileSize=FileSize_Temp;
+        if (BitRate_Before)
+        {
+            float64 BitRate_After=((float64)StreamSize_Temp)*8000/Duration_Temp;
+            if (BitRate_Before>BitRate_After*0.999 && BitRate_Before<BitRate_After*1.001)
+                MI->Fill(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_BitRate), BitRate_Before, 0, true); //In case of similar bitrate, there is great chance hte compute bit rate is different due to aproximation errors only, using the previous one. TODO: find a better way to detect it
+        }
     }
 
     //Frame rate if available from container
@@ -1188,6 +1329,8 @@ MediaInfo_Internal* File__ReferenceFilesHelper::MI_Create()
     #if MEDIAINFO_ADVANCED
         if (Config->File_IgnoreSequenceFileSize_Get())
             MI_Temp->Option(__T("File_IgnoreSequenceFileSize"), __T("1"));
+        if (Config->File_IgnoreSequenceFilesCount_Get())
+            MI_Temp->Option(__T("File_IgnoreSequenceFilesCount"), __T("1"));
         if (Config->File_Source_List_Get())
             MI_Temp->Option(__T("File_Source_List"), __T("1"));
     #endif //MEDIAINFO_ADVANCED
@@ -1196,8 +1339,12 @@ MediaInfo_Internal* File__ReferenceFilesHelper::MI_Create()
             MI_Temp->Option(__T("File_MD5"), __T("1"));
     #endif //MEDIAINFO_MD5
     #if MEDIAINFO_EVENTS
+        MI_Temp->Config.Config_PerPackage=Config->Config_PerPackage;
         if (Config->Event_CallBackFunction_IsSet())
+        {
             MI_Temp->Option(__T("File_Event_CallBackFunction"), Config->Event_CallBackFunction_Get());
+            MI_Temp->Config.Config_PerPackage->Event_CallBackFunction_Set(Config->Event_CallBackFunction_Get());
+        }
         MI_Temp->Config.File_Names_RootDirectory=FileName(MI->File_Name).Path_Get();
         if (Reference->FileNames.size()>1)
             MI_Temp->Option(__T("File_TestContinuousFileNames"), __T("0"));
@@ -1338,7 +1485,7 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                                 if (Reference->MI)
                                 {
                                     Ztring Result;
-                                    if (Reference->CompleteDuration.empty() || DurationM<Reference->CompleteDuration[1]->Demux_Offset_DTS)
+                                    if (Reference->CompleteDuration.empty() || DurationM<Reference->CompleteDuration[1].Demux_Offset_DTS)
                                     {
                                         Reference->CompleteDuration_Pos=0;
                                         Result=Reference->MI->Option(__T("File_Seek"), DurationS);
@@ -1346,10 +1493,10 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                                     else
                                     {
                                         size_t CompleteDuration_Pos_Temp=1;
-                                        while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && DurationM>=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->Demux_Offset_DTS)
+                                        while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && DurationM>=Reference->CompleteDuration[CompleteDuration_Pos_Temp].Demux_Offset_DTS)
                                             CompleteDuration_Pos_Temp++;
                                         CompleteDuration_Pos_Temp--;
-                                        Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->MI->Option(__T("File_Seek"), DurationS);
+                                        Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp].MI->Option(__T("File_Seek"), DurationS);
                                         if (Result.empty())
                                             Reference->CompleteDuration_Pos=CompleteDuration_Pos_Temp;
                                     }
@@ -1416,7 +1563,7 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                             if (Reference->MI)
                             {
                                 Ztring Result;
-                                if (Reference->CompleteDuration.empty() || Duration<Reference->CompleteDuration[1]->Demux_Offset_DTS)
+                                if (Reference->CompleteDuration.empty() || Duration<Reference->CompleteDuration[1].Demux_Offset_DTS)
                                 {
                                     Reference->CompleteDuration_Pos=0;
                                     Result=Reference->MI->Option(__T("File_Seek"), DurationS);
@@ -1424,10 +1571,10 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                                 else
                                 {
                                     size_t CompleteDuration_Pos_Temp=1;
-                                    while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && Duration>=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->Demux_Offset_DTS)
+                                    while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && Duration>=Reference->CompleteDuration[CompleteDuration_Pos_Temp].Demux_Offset_DTS)
                                         CompleteDuration_Pos_Temp++;
                                     CompleteDuration_Pos_Temp--;
-                                    Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->MI->Option(__T("File_Seek"), DurationS);
+                                    Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp].MI->Option(__T("File_Seek"), DurationS);
                                     if (Result.empty())
                                         Reference->CompleteDuration_Pos=CompleteDuration_Pos_Temp;
                                 }
@@ -1453,7 +1600,7 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                             if (Reference->MI)
                             {
                                 Ztring Result;
-                                if (Reference->CompleteDuration.empty() || Value<Reference->CompleteDuration[1]->Demux_Offset_DTS)
+                                if (Reference->CompleteDuration.size()<2 || Value<Reference->CompleteDuration[1].Demux_Offset_DTS)
                                 {
                                     Reference->CompleteDuration_Pos=0;
                                     Result=Reference->MI->Option(__T("File_Seek"), Time);
@@ -1461,10 +1608,10 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                                 else
                                 {
                                     size_t CompleteDuration_Pos_Temp=1;
-                                    while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && Value>=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->Demux_Offset_DTS)
+                                    while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && Value>=Reference->CompleteDuration[CompleteDuration_Pos_Temp].Demux_Offset_DTS)
                                         CompleteDuration_Pos_Temp++;
                                     CompleteDuration_Pos_Temp--;
-                                    Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->MI->Option(__T("File_Seek"), Time);
+                                    Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp].MI->Option(__T("File_Seek"), Time);
                                     if (Result.empty())
                                         Reference->CompleteDuration_Pos=CompleteDuration_Pos_Temp;
                                 }
@@ -1494,7 +1641,7 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                             if (Reference->MI)
                             {
                                     Ztring Result;
-                                    if (Reference->CompleteDuration.empty() || Value<Reference->CompleteDuration[1]->Demux_Offset_Frame)
+                                    if (Reference->CompleteDuration.size()<2 || Value<Reference->CompleteDuration[1].Demux_Offset_Frame)
                                     {
                                         Reference->CompleteDuration_Pos=0;
                                         Result=Reference->MI->Option(__T("File_Seek"), __T("Frame=")+Ztring::ToZtring(Value));
@@ -1502,10 +1649,10 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                                     else
                                     {
                                         size_t CompleteDuration_Pos_Temp=1;
-                                        while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && Value>=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->Demux_Offset_Frame)
+                                        while (CompleteDuration_Pos_Temp<Reference->CompleteDuration.size() && Value>=Reference->CompleteDuration[CompleteDuration_Pos_Temp].Demux_Offset_Frame)
                                             CompleteDuration_Pos_Temp++;
                                         CompleteDuration_Pos_Temp--;
-                                        Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp]->MI->Option(__T("File_Seek"), __T("Frame=")+Ztring::ToZtring(Value-Reference->CompleteDuration[CompleteDuration_Pos_Temp]->Demux_Offset_Frame));
+                                        Result=Reference->CompleteDuration[CompleteDuration_Pos_Temp].MI->Option(__T("File_Seek"), __T("Frame=")+Ztring::ToZtring(Value-Reference->CompleteDuration[CompleteDuration_Pos_Temp].Demux_Offset_Frame));
                                         if (Result.empty())
                                             Reference->CompleteDuration_Pos=CompleteDuration_Pos_Temp;
                                     }
@@ -1563,7 +1710,7 @@ void File__ReferenceFilesHelper::FileSize_Compute ()
                 {
                     if (!Reference->CompleteDuration.empty())
                         for (size_t Pos=1; Pos<Reference->CompleteDuration.size(); Pos++)
-                            MI->Config->File_Size+=File::Size_Get(Reference->CompleteDuration[Pos]->FileName);
+                            MI->Config->File_Size+=File::Size_Get(Reference->CompleteDuration[Pos].FileName);
                 }
         }
         else
@@ -1577,7 +1724,7 @@ void File__ReferenceFilesHelper::FileSize_Compute ()
                             MI->Config->File_Size+=File::Size_Get(Reference->FileNames[Pos]);
                     else
                         for (size_t Pos=0; Pos<Reference->CompleteDuration.size(); Pos++)
-                            MI->Config->File_Size+=File::Size_Get(Reference->CompleteDuration[Pos]->FileName);
+                            MI->Config->File_Size+=File::Size_Get(Reference->CompleteDuration[Pos].FileName);
                 }
         }
     }
