@@ -97,6 +97,10 @@ File_SubRip::File_SubRip()
 
     //Init
     Frame_Count=0;
+    
+    //Temp
+    IsVTT=false;
+    HasBOM=false;
 }
 
 //***************************************************************************
@@ -116,37 +120,47 @@ bool File_SubRip::FileHeader_Begin()
     List.Separator_Set(0, __T("\n\n"));
     List.Separator_Set(1, __T("\n"));
 
+    if (Buffer[0]==0xEF
+     && Buffer[1]==0xBB
+     && Buffer[2]==0xBF)
+        HasBOM=true;
     bool IsLocal=false;
     Ztring Temp;
-    Temp.From_UTF8((const char*)Buffer, Buffer_Size>65536?65536:Buffer_Size);
+    Temp.From_UTF8((const char*)Buffer+(HasBOM?3:0), (Buffer_Size>65536?65536:Buffer_Size)-(HasBOM?3:0));
     if (Temp.empty())
     {
-        Temp.From_Local((const char*)Buffer, Buffer_Size>65536?65536:Buffer_Size); // Trying from local code page
+        Temp.From_Local((const char*)Buffer+(HasBOM?3:0), (Buffer_Size>65536?65536:Buffer_Size)-(HasBOM?3:0)); // Trying from local code page
         IsLocal=true;
     }
     Temp.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
     Temp.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
     List.Write(Temp);
 
-    size_t IsOk=0;
-    size_t IsNok=0;
-    for (size_t Pos=0; Pos<List.size(); Pos++)
+    if (List(0, 0)==__T("WEBVTT FILE") || List(0, 0)==__T("WEBVTT"))
+        IsVTT=true;
+        
+    if (!IsVTT)
     {
-        if (List(Pos, 0).To_int64u()==Pos+1)
-            IsOk++;
-        else
-            IsNok++;
+        size_t IsOk=0;
+        size_t IsNok=0;
+        for (size_t Pos=0; Pos<List.size(); Pos++)
+        {
+            if (List(Pos, 0).To_int64u()==Pos+1)
+                IsOk++;
+            else
+                IsNok++;
 
-        if (List(Pos, 1).size()>22 && List(Pos, 1)[2]==__T(':') && List(Pos, 1)[5]==__T(':') && List(Pos, 1).find(__T(" --> "))!=string::npos)
-            IsOk++;
-        else
-            IsNok++;
-    }
+            if (List(Pos, 1).size()>22 && List(Pos, 1)[2]==__T(':') && List(Pos, 1)[5]==__T(':') && List(Pos, 1).find(__T(" --> "))!=string::npos)
+                IsOk++;
+            else
+                IsNok++;
+        }
 
-    if (!IsOk || IsNok>IsOk/2)
-    {
-        Reject();
-        return true;
+        if (!IsOk || IsNok>IsOk/2)
+        {
+            Reject();
+            return true;
+        }
     }
 
     if (!IsSub && File_Size!=(int64u)-1 && Buffer_Size!=File_Size)
@@ -158,16 +172,16 @@ bool File_SubRip::FileHeader_Begin()
     if (!Status[IsAccepted])
     {
         Accept();
-        Fill(Stream_General, 0, General_Format, "SubRip");
+        Fill(Stream_General, 0, General_Format, IsVTT?"WebVTT":"SubRip");
         Stream_Prepare(Stream_Text);
-        Fill(Stream_Text, 0, "Format", "SubRip");
-        Fill(Stream_Text, 0, "Codec", "SubRip");
+        Fill(Stream_Text, 0, "Format", IsVTT?"WebVTT":"SubRip");
+        Fill(Stream_Text, 0, "Codec", IsVTT?"WebVTT":"SubRip");
     }
 
     if (IsLocal)
-        Temp.From_Local((const char*)Buffer, Buffer_Size);
+        Temp.From_Local((const char*)Buffer+(HasBOM?3:0), Buffer_Size-(HasBOM?3:0));
     else
-        Temp.From_UTF8((const char*)Buffer, Buffer_Size);
+        Temp.From_UTF8((const char*)Buffer+(HasBOM?3:0), Buffer_Size-(HasBOM?3:0));
     Temp.FindAndReplace(__T("\r\n"), __T("\n"), 0, Ztring_Recursive);
     Temp.FindAndReplace(__T("\r"), __T("\n"), 0, Ztring_Recursive);
     List.Write(Temp);
@@ -179,14 +193,20 @@ bool File_SubRip::FileHeader_Begin()
             if (Pos>=List.size())
                 break;
 
-            if (List[Pos].size()>=3)
+            if (List[Pos].size()>=3 || (IsVTT && List[Pos].size()>=2))
             {
-                Ztring PTS_Begin_String=List[Pos][1].SubString(Ztring(), __T(" --> "));
-                Ztring PTS_End_String=List[Pos][1].SubString(__T(" --> "), Ztring());
+                Ztring PTS_Begin_String=List[Pos][IsVTT?0:1].SubString(Ztring(), __T(" --> "));
+                Ztring PTS_End_String=List[Pos][IsVTT?0:1].SubString(__T(" --> "), Ztring());
+                if (IsVTT)
+                {
+                    size_t Extra_Pos=PTS_End_String.find(__T(' '));
+                    if (Extra_Pos!=string::npos)
+                        PTS_End_String.resize(Extra_Pos); //Discarding positioning
+                }
                 item Item;
                 Item.PTS_Begin=SubRip_str2timecode(PTS_Begin_String.To_UTF8().c_str());
                 Item.PTS_End=SubRip_str2timecode(PTS_End_String.To_UTF8().c_str());
-                for (size_t Pos2=2; Pos2<List[Pos].size(); Pos2++)
+                for (size_t Pos2=IsVTT?1:2; Pos2<List[Pos].size(); Pos2++)
                 {
                     List[Pos][Pos2].Trim();
                     Item.Content+=List[Pos][Pos2];
